# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.user_attributes import user_attributes_pb2 as scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2


class UserAttributeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSsoUserAttribute = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/CreateSsoUserAttribute',
                request_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeResponse.FromString,
                )
        self.ListSsoUserAttributes = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/ListSsoUserAttributes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.ListUserAttributesResponse.FromString,
                )
        self.UpdateSsoUserAttribute = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/UpdateSsoUserAttribute',
                request_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeResponse.FromString,
                )
        self.DeleteSsoUserAttribute = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/DeleteSsoUserAttribute',
                request_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.DeleteUserAttributeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateDirectoryUserAttribute = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/CreateDirectoryUserAttribute',
                request_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeResponse.FromString,
                )
        self.ListDirectoryUserAttributes = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/ListDirectoryUserAttributes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.ListUserAttributesResponse.FromString,
                )
        self.UpdateDirectoryUserAttribute = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/UpdateDirectoryUserAttribute',
                request_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeResponse.FromString,
                )
        self.DeleteDirectoryUserAttribute = channel.unary_unary(
                '/scalekit.v1.user_attributes.UserAttributeService/DeleteDirectoryUserAttribute',
                request_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.DeleteUserAttributeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class UserAttributeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateSsoUserAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSsoUserAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSsoUserAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSsoUserAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDirectoryUserAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryUserAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDirectoryUserAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDirectoryUserAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserAttributeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSsoUserAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSsoUserAttribute,
                    request_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeResponse.SerializeToString,
            ),
            'ListSsoUserAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSsoUserAttributes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.ListUserAttributesResponse.SerializeToString,
            ),
            'UpdateSsoUserAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSsoUserAttribute,
                    request_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeResponse.SerializeToString,
            ),
            'DeleteSsoUserAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSsoUserAttribute,
                    request_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.DeleteUserAttributeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateDirectoryUserAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDirectoryUserAttribute,
                    request_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeResponse.SerializeToString,
            ),
            'ListDirectoryUserAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryUserAttributes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.ListUserAttributesResponse.SerializeToString,
            ),
            'UpdateDirectoryUserAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDirectoryUserAttribute,
                    request_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeResponse.SerializeToString,
            ),
            'DeleteDirectoryUserAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDirectoryUserAttribute,
                    request_deserializer=scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.DeleteUserAttributeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.user_attributes.UserAttributeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserAttributeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateSsoUserAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/CreateSsoUserAttribute',
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeRequest.SerializeToString,
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSsoUserAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/ListSsoUserAttributes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.ListUserAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSsoUserAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/UpdateSsoUserAttribute',
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeRequest.SerializeToString,
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSsoUserAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/DeleteSsoUserAttribute',
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.DeleteUserAttributeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDirectoryUserAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/CreateDirectoryUserAttribute',
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeRequest.SerializeToString,
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.CreateUserAttributeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryUserAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/ListDirectoryUserAttributes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.ListUserAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDirectoryUserAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/UpdateDirectoryUserAttribute',
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeRequest.SerializeToString,
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.UpdateUserAttributeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDirectoryUserAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.user_attributes.UserAttributeService/DeleteDirectoryUserAttribute',
            scalekit_dot_v1_dot_user__attributes_dot_user__attributes__pb2.DeleteUserAttributeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/connected_accounts/connected_accounts.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7scalekit/v1/connected_accounts/connected_accounts.proto\x12\x1escalekit.v1.connected_accounts\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/options/options.proto\"\xfa\x06\n\x1cListConnectedAccountsRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12\x61\n\tconnector\x18\x03 \x01(\tB>\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x18r\x16\x10\x00\x18\x32\x32\x10^[a-zA-Z0-9_-]*$H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12U\n\x08provider\x18\x05 \x01(\tB9\x92\x41-2!Provider of the connected accountJ\x08\"google\"\xbaH\x06r\x04\x10\x00\x18\x32R\x08provider\x12^\n\tpage_size\x18\x06 \x01(\rBA\x92\x41\x35\x32/Number of connected accounts to return per pageJ\x02\x31\x30\xbaH\x06*\x04\x10\x64(\x00R\x08pageSize\x12l\n\npage_token\x18\x07 \x01(\tBM\x92\x41\x41\x32<Token for pagination, used to fetch the next page of resultsJ\x01\x31\xbaH\x06r\x04\x10\x00\x18\x64R\tpageToken\x12\\\n\x05query\x18\x08 \x01(\tBF\x92\x41:2)Search query to filter connected accountsJ\r\"search_term\"\xbaH\x06r\x04\x10\x00\x18\x64R\x05queryB\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifier\"\xd3\x03\n\x1dListConnectedAccountsResponse\x12\x66\n\x12\x63onnected_accounts\x18\x01 \x03(\x0b\x32\x37.scalekit.v1.connected_accounts.ConnectedAccountForListR\x11\x63onnectedAccounts\x12`\n\ntotal_size\x18\x02 \x01(\rBA\x92\x41>27Total number of connected accounts matching the requestJ\x03\x31\x30\x30R\ttotalSize\x12o\n\x0fnext_page_token\x18\x03 \x01(\tBG\x92\x41;2\"Token for the next page of resultsJ\x15\"next_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rnextPageToken\x12w\n\x0fprev_page_token\x18\x04 \x01(\tBO\x92\x41\x43\x32&Token for the previous page of resultsJ\x19\"previous_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rprevPageToken\"\xf5\x05\n\x1eSearchConnectedAccountsRequest\x12\xb9\x01\n\x05query\x18\x01 \x01(\tB\xa2\x01\x92\x41\x91\x01\x32\x86\x01Search term to match against connected account identifiers, providers, or connectors. Must be at least 3 characters. Case insensitive.J\x06google\xbaH\nr\x05\x10\x03\x18\xc8\x01\xc8\x01\x01R\x05query\x12\x85\x01\n\tpage_size\x18\x02 \x01(\rBh\x92\x41^2XMaximum number of connected accounts to return per page. Value must be between 1 and 30.J\x02\x33\x30\xbaH\x04*\x02\x18\x1eR\x08pageSize\x12\xa5\x01\n\npage_token\x18\x03 \x01(\tB\x85\x01\x92\x41\x81\x01\x32\x61Token from a previous response for pagination. Provide this to retrieve the next page of results.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken:\xe6\x01\x92\x41\xe2\x01\n\x9c\x01*\x19Search Connected Accounts2\x7fSearch for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors2Aquery=google&page_size=30&page_token=eyJwYWdlIjoyLCJsaW1pdCI6MzB9\"\xda\x03\n\x1fSearchConnectedAccountsResponse\x12\x66\n\x12\x63onnected_accounts\x18\x01 \x03(\x0b\x32\x37.scalekit.v1.connected_accounts.ConnectedAccountForListR\x11\x63onnectedAccounts\x12\x65\n\ntotal_size\x18\x02 \x01(\rBF\x92\x41\x43\x32<Total number of connected accounts matching the search queryJ\x03\x31\x30\x30R\ttotalSize\x12o\n\x0fnext_page_token\x18\x03 \x01(\tBG\x92\x41;2\"Token for the next page of resultsJ\x15\"next_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rnextPageToken\x12w\n\x0fprev_page_token\x18\x04 \x01(\tBO\x92\x41\x43\x32&Token for the previous page of resultsJ\x19\"previous_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rprevPageToken\"\xb8\x06\n\x1d\x43reateConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12\x61\n\tconnector\x18\x03 \x01(\tB>\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x18r\x16\x10\x00\x18\x32\x32\x10^[a-zA-Z0-9_-]*$H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12\xbd\x02\n\x11\x63onnected_account\x18\x05 \x01(\x0b\x32\x36.scalekit.v1.connected_accounts.CreateConnectedAccountB\xd7\x01\x92\x41\xcd\x01\x32*Details of the connected account to createJ\x9e\x01{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\xbaH\x03\xc8\x01\x01R\x10\x63onnectedAccountB\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifier\"\xaf\x01\n\x1e\x43reateConnectedAccountResponse\x12\x8c\x01\n\x11\x63onnected_account\x18\x01 \x01(\x0b\x32\x30.scalekit.v1.connected_accounts.ConnectedAccountB-\x92\x41*2(Details of the created connected accountR\x10\x63onnectedAccount\"\x96\x07\n\x1dUpdateConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12O\n\tconnector\x18\x03 \x01(\tB,\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x06r\x04\x10\x00\x18\x32H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12g\n\x02id\x18\x06 \x01(\tBR\x92\x41\x41\x32\x35Unique identifier for the connected account to updateJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x12\xbd\x02\n\x11\x63onnected_account\x18\x05 \x01(\x0b\x32\x36.scalekit.v1.connected_accounts.UpdateConnectedAccountB\xd7\x01\x92\x41\xcd\x01\x32*Details of the connected account to updateJ\x9e\x01{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\xbaH\x03\xc8\x01\x01R\x10\x63onnectedAccountB\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\"\xaf\x01\n\x1eUpdateConnectedAccountResponse\x12\x8c\x01\n\x11\x63onnected_account\x18\x01 \x01(\x0b\x32\x30.scalekit.v1.connected_accounts.ConnectedAccountB-\x92\x41*2(Details of the updated connected accountR\x10\x63onnectedAccount\"\xe8\x04\n\x1d\x44\x65leteConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12\x61\n\tconnector\x18\x03 \x01(\tB>\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x18r\x16\x10\x00\x18\x32\x32\x10^[a-zA-Z0-9_-]*$H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12g\n\x02id\x18\x05 \x01(\tBR\x92\x41\x41\x32\x35Unique identifier for the connected account to deleteJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x42\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\" \n\x1e\x44\x65leteConnectedAccountResponse\"\xd5\x04\n&GetMagicLinkForConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12O\n\tconnector\x18\x03 \x01(\tB,\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x06r\x04\x10\x00\x18\x32H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12]\n\x02id\x18\x05 \x01(\tBH\x92\x41\x37\x32+Unique identifier for the connected accountJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x42\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\"\x99\x01\n.GetMagicLinkForConnectedAccountRedirectRequest\x12g\n\x0bredirect_to\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 R\nredirectTo\"\x9c\x02\n\'GetMagicLinkForConnectedAccountResponse\x12r\n\x04link\x18\x01 \x01(\tB^\x92\x41[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"R\x04link\x12}\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBI\x92\x41\x46\x32,Expiry timestamp for the authentication linkJ\x16\"2024-03-20T15:04:05Z\"R\x06\x65xpiry\"\xb1\x02\n/GetMagicLinkForConnectedAccountRedirectResponse\x12\x7f\n\x0bredirect_to\x18\x01 \x01(\tB^\x92\x41[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"R\nredirectTo\x12}\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBI\x92\x41\x46\x32,Expiry timestamp for the authentication linkJ\x16\"2024-03-20T15:04:05Z\"R\x06\x65xpiry\"\xd5\x04\n&GetConnectedAccountByIdentifierRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12O\n\tconnector\x18\x03 \x01(\tB,\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x06r\x04\x10\x00\x18\x32H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12]\n\x02id\x18\x05 \x01(\tBH\x92\x41\x37\x32+Unique identifier for the connected accountJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x42\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\"\x88\x01\n\'GetConnectedAccountByIdentifierResponse\x12]\n\x11\x63onnected_account\x18\x01 \x01(\x0b\x32\x30.scalekit.v1.connected_accounts.ConnectedAccountR\x10\x63onnectedAccount\"\xff\x05\n\x10\x43onnectedAccount\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12G\n\x06status\x18\x03 \x01(\x0e\x32/.scalekit.v1.connected_accounts.ConnectorStatusR\x06status\x12\\\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32-.scalekit.v1.connected_accounts.ConnectorTypeR\x11\x61uthorizationType\x12i\n\x15\x61uthorization_details\x18\x05 \x01(\x0b\x32\x34.scalekit.v1.connected_accounts.AuthorizationDetailsR\x14\x61uthorizationDetails\x12\x44\n\x10token_expires_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0etokenExpiresAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x1c\n\tconnector\x18\x08 \x01(\tR\tconnector\x12<\n\x0clast_used_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAt\x12X\n\x02id\x18\n \x01(\tBH\x92\x41\x37\x32+Unique identifier for the connected accountJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_R\x02id\x12\x66\n\rconnection_id\x18\x0b \x01(\tBA\x92\x41\x35\x32\'Connection ID for the connected accountJ\n\"conn_123\"\xbaH\x06r\x04\x10\x00\x18 R\x0c\x63onnectionId\"\xfd\x01\n\x16\x43reateConnectedAccount\x12\xac\x01\n\x15\x61uthorization_details\x18\x05 \x01(\x0b\x32\x34.scalekit.v1.connected_accounts.AuthorizationDetailsBA\x92\x41\x38\x32\x36\x44\x65tails of the authorization for the connected account\xbaH\x03\xc8\x01\x01R\x14\x61uthorizationDetailsJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\xf7\x01\n\x16UpdateConnectedAccount\x12\xac\x01\n\x15\x61uthorization_details\x18\x05 \x01(\x0b\x32\x34.scalekit.v1.connected_accounts.AuthorizationDetailsBA\x92\x41\x38\x32\x36\x44\x65tails of the authorization for the connected account\xbaH\x03\xc8\x01\x01R\x14\x61uthorizationDetailsJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\xd7\x04\n\x17\x43onnectedAccountForList\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12G\n\x06status\x18\x03 \x01(\x0e\x32/.scalekit.v1.connected_accounts.ConnectorStatusR\x06status\x12\\\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32-.scalekit.v1.connected_accounts.ConnectorTypeR\x11\x61uthorizationType\x12\x44\n\x10token_expires_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0etokenExpiresAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x1c\n\tconnector\x18\x08 \x01(\tR\tconnector\x12<\n\x0clast_used_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAt\x12\x0e\n\x02id\x18\n \x01(\tR\x02id\x12\x66\n\rconnection_id\x18\x0b \x01(\tBA\x92\x41\x35\x32\'Connection ID for the connected accountJ\n\"conn_123\"\xbaH\x06r\x04\x10\x00\x18 R\x0c\x63onnectionIdJ\x04\x08\x05\x10\x06\"\xbf\x01\n\x14\x41uthorizationDetails\x12M\n\x0boauth_token\x18\x01 \x01(\x0b\x32*.scalekit.v1.connected_accounts.OauthTokenH\x00R\noauthToken\x12M\n\x0bstatic_auth\x18\x02 \x01(\x0b\x32*.scalekit.v1.connected_accounts.StaticAuthH\x00R\nstaticAuthB\t\n\x07\x64\x65tails\"l\n\nOauthToken\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12#\n\rrefresh_token\x18\x02 \x01(\tR\x0crefreshToken\x12\x16\n\x06scopes\x18\x03 \x03(\tR\x06scopes\"?\n\nStaticAuth\x12\x31\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x64\x65tails*_\n\x0f\x43onnectorStatus\x12!\n\x1d\x43ONNECTION_STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x12\x10\n\x0cPENDING_AUTH\x10\x03*\x81\x01\n\rConnectorType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05OAUTH\x10\x01\x12\x0b\n\x07\x41PI_KEY\x10\x02\x12\x0e\n\nBASIC_AUTH\x10\x03\x12\x10\n\x0c\x42\x45\x41RER_TOKEN\x10\x04\x12\n\n\x06\x43USTOM\x10\x05\x12\t\n\x05\x42\x41SIC\x10\x06\x32\xb0\x15\n\x17\x43onnectedAccountService\x12\xd0\x02\n\x15ListConnectedAccounts\x12<.scalekit.v1.connected_accounts.ListConnectedAccountsRequest\x1a=.scalekit.v1.connected_accounts.ListConnectedAccountsResponse\"\xb9\x01\x92\x41\x7f\n\rAppConnectors\x12\x1bList all connected accounts\x1aQList all connected accounts, optionally filtered by connection and/or identifier.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/connected_accounts\x12\x8a\x03\n\x17SearchConnectedAccounts\x12>.scalekit.v1.connected_accounts.SearchConnectedAccountsRequest\x1a?.scalekit.v1.connected_accounts.SearchConnectedAccountsResponse\"\xed\x01\x92\x41\xab\x01\n\rAppConnectors\x12\x19Search connected accounts\x1a\x7fSearch for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02#\x12!/api/v1/connected_accounts:search\x12\xa3\x02\n\x16\x43reateConnectedAccount\x12=.scalekit.v1.connected_accounts.CreateConnectedAccountRequest\x1a>.scalekit.v1.connected_accounts.CreateConnectedAccountResponse\"\x89\x01\x92\x41L\n\rAppConnectors\x12\x1a\x43reate a connected account\x1a\x1f\x43reate a new connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/connected_accounts:\x01*\x12\xa9\x02\n\x16UpdateConnectedAccount\x12=.scalekit.v1.connected_accounts.UpdateConnectedAccountRequest\x1a>.scalekit.v1.connected_accounts.UpdateConnectedAccountResponse\"\x8f\x01\x92\x41R\n\rAppConnectors\x12\x1aUpdate a connected account\x1a%Update an existing connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/connected_accounts:\x01*\x12\xa6\x02\n\x16\x44\x65leteConnectedAccount\x12=.scalekit.v1.connected_accounts.DeleteConnectedAccountRequest\x1a>.scalekit.v1.connected_accounts.DeleteConnectedAccountResponse\"\x8c\x01\x92\x41H\n\rAppConnectors\x12\x1a\x44\x65lete a connected account\x1a\x1b\x44\x65lete a connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02&\"!/api/v1/connected_accounts:delete:\x01*\x12\xe1\x02\n\x1fGetMagicLinkForConnectedAccount\x12\x46.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountRequest\x1aG.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountResponse\"\xac\x01\x92\x41\x64\n\rAppConnectors\x12(Get a magic link for a connected account\x1a)Get a magic link for a connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02*\"%/api/v1/connected_accounts/magic_link:\x01*\x12\xcc\x02\n\x17GetConnectedAccountAuth\x12\x46.scalekit.v1.connected_accounts.GetConnectedAccountByIdentifierRequest\x1aG.scalekit.v1.connected_accounts.GetConnectedAccountByIdentifierResponse\"\x9f\x01\x92\x41`\n\rAppConnectors\x12#Get connected account by identifier\x1a*Get a connected account by its identifier.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/connected_accounts/auth\x12\x86\x03\n+GetMagicLinkForConnectedAccountWithRedirect\x12N.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountRedirectRequest\x1aO.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountRedirectResponse\"\xb5\x01\x92\x41\x64\n\rAppConnectors\x12(Get a magic link for a connected account\x1a)Get a magic link for a connected account.\x82\xb5\x18\x02\x18\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x33\"./api/v1/connected_accounts/magic_link/redirect:\x01*B>Z<github.com/scalekit-inc/scalekit/pkg/grpc/connected_accountsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.connected_accounts.connected_accounts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/scalekit-inc/scalekit/pkg/grpc/connected_accounts'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\030r\026\020\000\03022\020^[a-zA-Z0-9_-]*$'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['provider']._serialized_options = b'\222A-2!Provider of the connected accountJ\010\"google\"\272H\006r\004\020\000\0302'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222A52/Number of connected accounts to return per pageJ\00210\272H\006*\004\020d(\000'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222AA2<Token for pagination, used to fetch the next page of resultsJ\0011\272H\006r\004\020\000\030d'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._serialized_options = b'\222A:2)Search query to filter connected accountsJ\r\"search_term\"\272H\006r\004\020\000\030d'
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222A>27Total number of connected accounts matching the requestJ\003100'
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222A;2\"Token for the next page of resultsJ\025\"next_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AC2&Token for the previous page of resultsJ\031\"previous_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._serialized_options = b'\222A\221\0012\206\001Search term to match against connected account identifiers, providers, or connectors. Must be at least 3 characters. Case insensitive.J\006google\272H\nr\005\020\003\030\310\001\310\001\001'
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222A^2XMaximum number of connected accounts to return per page. Value must be between 1 and 30.J\00230\272H\004*\002\030\036'
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222A\201\0012aToken from a previous response for pagination. Provide this to retrieve the next page of results.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._serialized_options = b'\222A\342\001\n\234\001*\031Search Connected Accounts2\177Search for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors2Aquery=google&page_size=30&page_token=eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222AC2<Total number of connected accounts matching the search queryJ\003100'
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222A;2\"Token for the next page of resultsJ\025\"next_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AC2&Token for the previous page of resultsJ\031\"previous_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\030r\026\020\000\03022\020^[a-zA-Z0-9_-]*$'
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._serialized_options = b'\222A\315\0012*Details of the connected account to createJ\236\001{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\272H\003\310\001\001'
  _globals['_CREATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._serialized_options = b'\222A*2(Details of the created connected account'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\006r\004\020\000\0302'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\222AA25Unique identifier for the connected account to updateJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._serialized_options = b'\222A\315\0012*Details of the connected account to updateJ\236\001{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\272H\003\310\001\001'
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._serialized_options = b'\222A*2(Details of the updated connected account'
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\030r\026\020\000\03022\020^[a-zA-Z0-9_-]*$'
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\222AA25Unique identifier for the connected account to deleteJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\006r\004\020\000\0302'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\222A72+Unique identifier for the connected accountJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST'].fields_by_name['redirect_to']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST'].fields_by_name['redirect_to']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['link']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['link']._serialized_options = b'\222A[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['expiry']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['expiry']._serialized_options = b'\222AF2,Expiry timestamp for the authentication linkJ\026\"2024-03-20T15:04:05Z\"'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['redirect_to']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['redirect_to']._serialized_options = b'\222A[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['expiry']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['expiry']._serialized_options = b'\222AF2,Expiry timestamp for the authentication linkJ\026\"2024-03-20T15:04:05Z\"'
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\006r\004\020\000\0302'
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['id']._serialized_options = b'\222A72+Unique identifier for the connected accountJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_CONNECTEDACCOUNT'].fields_by_name['id']._loaded_options = None
  _globals['_CONNECTEDACCOUNT'].fields_by_name['id']._serialized_options = b'\222A72+Unique identifier for the connected accountJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_CONNECTEDACCOUNT'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CONNECTEDACCOUNT'].fields_by_name['connection_id']._serialized_options = b'\222A52\'Connection ID for the connected accountJ\n\"conn_123\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._serialized_options = b'\222A826Details of the authorization for the connected account\272H\003\310\001\001'
  _globals['_UPDATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._serialized_options = b'\222A826Details of the authorization for the connected account\272H\003\310\001\001'
  _globals['_CONNECTEDACCOUNTFORLIST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CONNECTEDACCOUNTFORLIST'].fields_by_name['connection_id']._serialized_options = b'\222A52\'Connection ID for the connected accountJ\n\"conn_123\"\272H\006r\004\020\000\030 '
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['ListConnectedAccounts']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['ListConnectedAccounts']._serialized_options = b'\222A\177\n\rAppConnectors\022\033List all connected accounts\032QList all connected accounts, optionally filtered by connection and/or identifier.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\034\022\032/api/v1/connected_accounts'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['SearchConnectedAccounts']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['SearchConnectedAccounts']._serialized_options = b'\222A\253\001\n\rAppConnectors\022\031Search connected accounts\032\177Search for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002#\022!/api/v1/connected_accounts:search'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['CreateConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['CreateConnectedAccount']._serialized_options = b'\222AL\n\rAppConnectors\022\032Create a connected account\032\037Create a new connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\037\"\032/api/v1/connected_accounts:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['UpdateConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['UpdateConnectedAccount']._serialized_options = b'\222AR\n\rAppConnectors\022\032Update a connected account\032%Update an existing connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\037\032\032/api/v1/connected_accounts:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['DeleteConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['DeleteConnectedAccount']._serialized_options = b'\222AH\n\rAppConnectors\022\032Delete a connected account\032\033Delete a connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002&\"!/api/v1/connected_accounts:delete:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccount']._serialized_options = b'\222Ad\n\rAppConnectors\022(Get a magic link for a connected account\032)Get a magic link for a connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002*\"%/api/v1/connected_accounts/magic_link:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetConnectedAccountAuth']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetConnectedAccountAuth']._serialized_options = b'\222A`\n\rAppConnectors\022#Get connected account by identifier\032*Get a connected account by its identifier.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002!\022\037/api/v1/connected_accounts/auth'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccountWithRedirect']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccountWithRedirect']._serialized_options = b'\222Ad\n\rAppConnectors\022(Get a magic link for a connected account\032)Get a magic link for a connected account.\202\265\030\002\030\001\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\0023\"./api/v1/connected_accounts/magic_link/redirect:\001*'
  _globals['_CONNECTORSTATUS']._serialized_start=10052
  _globals['_CONNECTORSTATUS']._serialized_end=10147
  _globals['_CONNECTORTYPE']._serialized_start=10150
  _globals['_CONNECTORTYPE']._serialized_end=10279
  _globals['_LISTCONNECTEDACCOUNTSREQUEST']._serialized_start=359
  _globals['_LISTCONNECTEDACCOUNTSREQUEST']._serialized_end=1249
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE']._serialized_start=1252
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE']._serialized_end=1719
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._serialized_start=1722
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._serialized_end=2479
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE']._serialized_start=2482
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE']._serialized_end=2956
  _globals['_CREATECONNECTEDACCOUNTREQUEST']._serialized_start=2959
  _globals['_CREATECONNECTEDACCOUNTREQUEST']._serialized_end=3783
  _globals['_CREATECONNECTEDACCOUNTRESPONSE']._serialized_start=3786
  _globals['_CREATECONNECTEDACCOUNTRESPONSE']._serialized_end=3961
  _globals['_UPDATECONNECTEDACCOUNTREQUEST']._serialized_start=3964
  _globals['_UPDATECONNECTEDACCOUNTREQUEST']._serialized_end=4882
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE']._serialized_start=4885
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE']._serialized_end=5060
  _globals['_DELETECONNECTEDACCOUNTREQUEST']._serialized_start=5063
  _globals['_DELETECONNECTEDACCOUNTREQUEST']._serialized_end=5679
  _globals['_DELETECONNECTEDACCOUNTRESPONSE']._serialized_start=5681
  _globals['_DELETECONNECTEDACCOUNTRESPONSE']._serialized_end=5713
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST']._serialized_start=5716
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST']._serialized_end=6313
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST']._serialized_start=6316
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST']._serialized_end=6469
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE']._serialized_start=6472
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE']._serialized_end=6756
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE']._serialized_start=6759
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE']._serialized_end=7064
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST']._serialized_start=7067
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST']._serialized_end=7664
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERRESPONSE']._serialized_start=7667
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERRESPONSE']._serialized_end=7803
  _globals['_CONNECTEDACCOUNT']._serialized_start=7806
  _globals['_CONNECTEDACCOUNT']._serialized_end=8573
  _globals['_CREATECONNECTEDACCOUNT']._serialized_start=8576
  _globals['_CREATECONNECTEDACCOUNT']._serialized_end=8829
  _globals['_UPDATECONNECTEDACCOUNT']._serialized_start=8832
  _globals['_UPDATECONNECTEDACCOUNT']._serialized_end=9079
  _globals['_CONNECTEDACCOUNTFORLIST']._serialized_start=9082
  _globals['_CONNECTEDACCOUNTFORLIST']._serialized_end=9681
  _globals['_AUTHORIZATIONDETAILS']._serialized_start=9684
  _globals['_AUTHORIZATIONDETAILS']._serialized_end=9875
  _globals['_OAUTHTOKEN']._serialized_start=9877
  _globals['_OAUTHTOKEN']._serialized_end=9985
  _globals['_STATICAUTH']._serialized_start=9987
  _globals['_STATICAUTH']._serialized_end=10050
  _globals['_CONNECTEDACCOUNTSERVICE']._serialized_start=10282
  _globals['_CONNECTEDACCOUNTSERVICE']._serialized_end=13018
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/mcp/mcp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19scalekit/v1/mcp/mcp.proto\x12\x0fscalekit.v1.mcp\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/options/options.proto\"q\n\x10\x43reateMcpRequest\x12]\n\x03mcp\x18\x01 \x01(\x0b\x32\x14.scalekit.v1.mcp.McpB5\x92\x41,2*MCP tool configuration to create or update\xbaH\x03\xc8\x01\x01R\x03mcp\"X\n\x11\x43reateMcpResponse\x12\x43\n\x03mcp\x18\x01 \x01(\x0b\x32\x14.scalekit.v1.mcp.McpB\x1b\x92\x41\x18\x32\x16The MCP server detailsR\x03mcp\"\x93\x03\n\x03Mcp\x12\x38\n\x02id\x18\x01 \x01(\tB(\x92\x41\"2\x15Unique ID of the toolJ\t\"res_123\"\xe0\x41\x03R\x02id\x12x\n\rtool_mappings\x18\x02 \x03(\x0b\x32\x1c.scalekit.v1.mcp.ToolMappingB5\x92\x41\'2\x1bProvider name (e.g. GOOGLE)J\x08\"GOOGLE\"\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x0ctoolMappings\x12\x84\x01\n\x1c\x63onnected_account_identifier\x18\x03 \x01(\tBB\x92\x41\x35\x32$Identifier for the connected accountJ\r\"account_123\"\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x1a\x63onnectedAccountIdentifier\x12Q\n\x03url\x18\x04 \x01(\tB?\x92\x41\x39\x32\x15Unique ID of the toolJ \"https://example.com/mcp/v1/abc\"\xe0\x41\x03R\x03url\"\x96\x02\n\x0bToolMapping\x12\\\n\ntool_names\x18\x01 \x03(\tB=\x92\x41:2\x12List of tool namesJ$[\"GMAIL_FETCH_MAILS\", \"LIST_DRAFTS\"]R\ttoolNames\x12\\\n\x0f\x63onnection_name\x18\x02 \x01(\tB3\x92\x41*2\x1c\x43onnection name for the toolJ\n\"MY-GMAIL\"\xbaH\x03\xc8\x01\x01R\x0e\x63onnectionName\x12K\n\x06status\x18\x03 \x01(\tB3\x92\x41-2!Authentication status of the toolJ\x08\"ACTIVE\"\xe0\x41\x03R\x06status\"L\n\rGetMcpRequest\x12;\n\x06mcp_id\x18\x01 \x01(\tB$\x92\x41\x1b\x32\x19ID of the MCP to retrieve\xbaH\x03\xc8\x01\x01R\x05mcpId\"N\n\x0eGetMcpResponse\x12<\n\x03mcp\x18\x01 \x01(\x0b\x32\x14.scalekit.v1.mcp.McpB\x14\x92\x41\x11\x32\x0fThe MCP detailsR\x03mcp\"\x84\x02\n\x0eListMcpRequest\x12>\n\x06\x66ilter\x18\x01 \x01(\x0b\x32&.scalekit.v1.mcp.ListMcpRequest.FilterR\x06\x66ilter\x1a\xb1\x01\n\x06\x46ilter\x12m\n\x1c\x63onnected_account_identifier\x18\x01 \x01(\tB+\x92\x41(2&Filter by connected account identifierR\x1a\x63onnectedAccountIdentifier\x12\x38\n\nlink_token\x18\x02 \x01(\tB\x19\x92\x41\x16\x32\x14\x46ilter by link tokenR\tlinkToken\"N\n\x0fListMcpResponse\x12;\n\x04mcps\x18\x01 \x03(\x0b\x32\x14.scalekit.v1.mcp.McpB\x11\x92\x41\x0e\x32\x0cList of MCPsR\x04mcps\"M\n\x10\x44\x65leteMcpRequest\x12\x39\n\x06mcp_id\x18\x01 \x01(\tB\"\x92\x41\x19\x32\x17ID of the MCP to delete\xbaH\x03\xc8\x01\x01R\x05mcpId\"\x13\n\x11\x44\x65leteMcpResponse2\xaf\x07\n\nMcpService\x12\xa8\x02\n\tCreateMcp\x12!.scalekit.v1.mcp.CreateMcpRequest\x1a\".scalekit.v1.mcp.CreateMcpResponse\"\xd3\x01\x92\x41\xb1\x01\n\x03mcp\x12\x41\x43reates or returns the existing MCP with the given configuration.\x1agCreates a new MCP for the configuration. If same configuration exists, it will return the existing MCP.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x12\"\x0b/api/v1/mcp:\x03mcp\x12\xbe\x01\n\x06GetMcp\x12\x1e.scalekit.v1.mcp.GetMcpRequest\x1a\x1f.scalekit.v1.mcp.GetMcpResponse\"s\x92\x41N\n\x03mcp\x12\x1aGet an existing MCP by ID.\x1a+Returns the existing MCP with the given ID.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/mcp/{mcp_id}\x12\xf9\x01\n\x07ListMcp\x12\x1f.scalekit.v1.mcp.ListMcpRequest\x1a .scalekit.v1.mcp.ListMcpResponse\"\xaa\x01\x92\x41\x8d\x01\n\x03mcp\x12 List MCPs with optional filters.\x1a\x64Returns a list of existing MCPs, optionally filtered by connected_account_identifier and link_token.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\r\x12\x0b/api/v1/mcp\x12\xb8\x01\n\tDeleteMcp\x12!.scalekit.v1.mcp.DeleteMcpRequest\x1a\".scalekit.v1.mcp.DeleteMcpResponse\"d\x92\x41?\n\x03mcp\x12\x14\x44\x65lete an MCP by ID.\x1a\"Deletes the MCP with the given ID.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x16*\x14/api/v1/mcp/{mcp_id}B/Z-github.com/scalekit-inc/scalekit/pkg/grpc/mcpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.mcp.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/scalekit-inc/scalekit/pkg/grpc/mcp'
  _globals['_CREATEMCPREQUEST'].fields_by_name['mcp']._loaded_options = None
  _globals['_CREATEMCPREQUEST'].fields_by_name['mcp']._serialized_options = b'\222A,2*MCP tool configuration to create or update\272H\003\310\001\001'
  _globals['_CREATEMCPRESPONSE'].fields_by_name['mcp']._loaded_options = None
  _globals['_CREATEMCPRESPONSE'].fields_by_name['mcp']._serialized_options = b'\222A\0302\026The MCP server details'
  _globals['_MCP'].fields_by_name['id']._loaded_options = None
  _globals['_MCP'].fields_by_name['id']._serialized_options = b'\222A\"2\025Unique ID of the toolJ\t\"res_123\"\340A\003'
  _globals['_MCP'].fields_by_name['tool_mappings']._loaded_options = None
  _globals['_MCP'].fields_by_name['tool_mappings']._serialized_options = b'\222A\'2\033Provider name (e.g. GOOGLE)J\010\"GOOGLE\"\272H\010\222\001\002\010\001\310\001\001'
  _globals['_MCP'].fields_by_name['connected_account_identifier']._loaded_options = None
  _globals['_MCP'].fields_by_name['connected_account_identifier']._serialized_options = b'\222A52$Identifier for the connected accountJ\r\"account_123\"\272H\007r\002\020\001\310\001\001'
  _globals['_MCP'].fields_by_name['url']._loaded_options = None
  _globals['_MCP'].fields_by_name['url']._serialized_options = b'\222A92\025Unique ID of the toolJ \"https://example.com/mcp/v1/abc\"\340A\003'
  _globals['_TOOLMAPPING'].fields_by_name['tool_names']._loaded_options = None
  _globals['_TOOLMAPPING'].fields_by_name['tool_names']._serialized_options = b'\222A:2\022List of tool namesJ$[\"GMAIL_FETCH_MAILS\", \"LIST_DRAFTS\"]'
  _globals['_TOOLMAPPING'].fields_by_name['connection_name']._loaded_options = None
  _globals['_TOOLMAPPING'].fields_by_name['connection_name']._serialized_options = b'\222A*2\034Connection name for the toolJ\n\"MY-GMAIL\"\272H\003\310\001\001'
  _globals['_TOOLMAPPING'].fields_by_name['status']._loaded_options = None
  _globals['_TOOLMAPPING'].fields_by_name['status']._serialized_options = b'\222A-2!Authentication status of the toolJ\010\"ACTIVE\"\340A\003'
  _globals['_GETMCPREQUEST'].fields_by_name['mcp_id']._loaded_options = None
  _globals['_GETMCPREQUEST'].fields_by_name['mcp_id']._serialized_options = b'\222A\0332\031ID of the MCP to retrieve\272H\003\310\001\001'
  _globals['_GETMCPRESPONSE'].fields_by_name['mcp']._loaded_options = None
  _globals['_GETMCPRESPONSE'].fields_by_name['mcp']._serialized_options = b'\222A\0212\017The MCP details'
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['connected_account_identifier']._loaded_options = None
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['connected_account_identifier']._serialized_options = b'\222A(2&Filter by connected account identifier'
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['link_token']._loaded_options = None
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['link_token']._serialized_options = b'\222A\0262\024Filter by link token'
  _globals['_LISTMCPRESPONSE'].fields_by_name['mcps']._loaded_options = None
  _globals['_LISTMCPRESPONSE'].fields_by_name['mcps']._serialized_options = b'\222A\0162\014List of MCPs'
  _globals['_DELETEMCPREQUEST'].fields_by_name['mcp_id']._loaded_options = None
  _globals['_DELETEMCPREQUEST'].fields_by_name['mcp_id']._serialized_options = b'\222A\0312\027ID of the MCP to delete\272H\003\310\001\001'
  _globals['_MCPSERVICE'].methods_by_name['CreateMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['CreateMcp']._serialized_options = b'\222A\261\001\n\003mcp\022ACreates or returns the existing MCP with the given configuration.\032gCreates a new MCP for the configuration. If same configuration exists, it will return the existing MCP.\202\265\030\002\030t\202\323\344\223\002\022\"\013/api/v1/mcp:\003mcp'
  _globals['_MCPSERVICE'].methods_by_name['GetMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['GetMcp']._serialized_options = b'\222AN\n\003mcp\022\032Get an existing MCP by ID.\032+Returns the existing MCP with the given ID.\202\265\030\002\030t\202\323\344\223\002\026\022\024/api/v1/mcp/{mcp_id}'
  _globals['_MCPSERVICE'].methods_by_name['ListMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['ListMcp']._serialized_options = b'\222A\215\001\n\003mcp\022 List MCPs with optional filters.\032dReturns a list of existing MCPs, optionally filtered by connected_account_identifier and link_token.\202\265\030\002\030t\202\323\344\223\002\r\022\013/api/v1/mcp'
  _globals['_MCPSERVICE'].methods_by_name['DeleteMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['DeleteMcp']._serialized_options = b'\222A?\n\003mcp\022\024Delete an MCP by ID.\032\"Deletes the MCP with the given ID.\202\265\030\002\030t\202\323\344\223\002\026*\024/api/v1/mcp/{mcp_id}'
  _globals['_CREATEMCPREQUEST']._serialized_start=374
  _globals['_CREATEMCPREQUEST']._serialized_end=487
  _globals['_CREATEMCPRESPONSE']._serialized_start=489
  _globals['_CREATEMCPRESPONSE']._serialized_end=577
  _globals['_MCP']._serialized_start=580
  _globals['_MCP']._serialized_end=983
  _globals['_TOOLMAPPING']._serialized_start=986
  _globals['_TOOLMAPPING']._serialized_end=1264
  _globals['_GETMCPREQUEST']._serialized_start=1266
  _globals['_GETMCPREQUEST']._serialized_end=1342
  _globals['_GETMCPRESPONSE']._serialized_start=1344
  _globals['_GETMCPRESPONSE']._serialized_end=1422
  _globals['_LISTMCPREQUEST']._serialized_start=1425
  _globals['_LISTMCPREQUEST']._serialized_end=1685
  _globals['_LISTMCPREQUEST_FILTER']._serialized_start=1508
  _globals['_LISTMCPREQUEST_FILTER']._serialized_end=1685
  _globals['_LISTMCPRESPONSE']._serialized_start=1687
  _globals['_LISTMCPRESPONSE']._serialized_end=1765
  _globals['_DELETEMCPREQUEST']._serialized_start=1767
  _globals['_DELETEMCPREQUEST']._serialized_end=1844
  _globals['_DELETEMCPRESPONSE']._serialized_start=1846
  _globals['_DELETEMCPRESPONSE']._serialized_end=1865
  _globals['_MCPSERVICE']._serialized_start=1868
  _globals['_MCPSERVICE']._serialized_end=2811
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/auditlogs/auditlogs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%scalekit/v1/auditlogs/auditlogs.proto\x12\x15scalekit.v1.auditlogs\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!scalekit/v1/options/options.proto\"\xf0\x01\n\x12ListAuthLogRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\rR\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x14\n\x05\x65mail\x18\x03 \x01(\tR\x05\x65mail\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x39\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\"\xcf\x01\n\x13ListAuthLogResponse\x12&\n\x0fnext_page_token\x18\x01 \x01(\tR\rnextPageToken\x12&\n\x0fprev_page_token\x18\x02 \x01(\tR\rprevPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\rR\ttotalSize\x12I\n\x0c\x61uthRequests\x18\x04 \x03(\x0b\x32%.scalekit.v1.auditlogs.AuthLogRequestR\x0c\x61uthRequests\"\xe4\x03\n\x0e\x41uthLogRequest\x12\'\n\x0forganization_id\x18\x01 \x01(\tR\x0eorganizationId\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\x12#\n\rconnection_id\x18\x03 \x01(\tR\x0c\x63onnectionId\x12&\n\x0f\x61uth_request_id\x18\x04 \x01(\tR\rauthRequestId\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12\'\n\x0f\x63onnection_type\x18\x06 \x01(\tR\x0e\x63onnectionType\x12/\n\x13\x63onnection_provider\x18\x07 \x01(\tR\x12\x63onnectionProvider\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12\x38\n\ttimestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12W\n\x12\x63onnection_details\x18\n \x03(\x0b\x32(.scalekit.v1.auditlogs.ConnectionDetailsR\x11\x63onnectionDetails\x12\x1a\n\x08workflow\x18\x0b \x01(\tR\x08workflow\"\xbb\x01\n\x11\x43onnectionDetails\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\x12\'\n\x0f\x63onnection_type\x18\x03 \x01(\tR\x0e\x63onnectionType\x12/\n\x13\x63onnection_provider\x18\x04 \x01(\tR\x12\x63onnectionProvider2\xb2\x01\n\x10\x41uditLogsService\x12\x9d\x01\n\x10ListAuthRequests\x12).scalekit.v1.auditlogs.ListAuthLogRequest\x1a*.scalekit.v1.auditlogs.ListAuthLogResponse\"2\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02&\x12$/api/v1/logs/authentication/requestsB5Z3github.com/scalekit-inc/scalekit/pkg/grpc/auditlogsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.auditlogs.auditlogs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/scalekit-inc/scalekit/pkg/grpc/auditlogs'
  _globals['_AUDITLOGSSERVICE'].methods_by_name['ListAuthRequests']._loaded_options = None
  _globals['_AUDITLOGSSERVICE'].methods_by_name['ListAuthRequests']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002&\022$/api/v1/logs/authentication/requests'
  _globals['_LISTAUTHLOGREQUEST']._serialized_start=192
  _globals['_LISTAUTHLOGREQUEST']._serialized_end=432
  _globals['_LISTAUTHLOGRESPONSE']._serialized_start=435
  _globals['_LISTAUTHLOGRESPONSE']._serialized_end=642
  _globals['_AUTHLOGREQUEST']._serialized_start=645
  _globals['_AUTHLOGREQUEST']._serialized_end=1129
  _globals['_CONNECTIONDETAILS']._serialized_start=1132
  _globals['_CONNECTIONDETAILS']._serialized_end=1319
  _globals['_AUDITLOGSSERVICE']._serialized_start=1322
  _globals['_AUDITLOGSSERVICE']._serialized_end=1500
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CustomDomainStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[CustomDomainStatus]
    PENDING: _ClassVar[CustomDomainStatus]
    ACTIVE: _ClassVar[CustomDomainStatus]
    FAILED: _ClassVar[CustomDomainStatus]
    INITIAL: _ClassVar[CustomDomainStatus]

class AssetCategory(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ASSET_CATEGORY_UNSPECIFIED: _ClassVar[AssetCategory]
    PORTAL_CUSTOMIZATION_IMAGE: _ClassVar[AssetCategory]

class OrgUserRelationshipType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OrgUserRelationshipType_UNSPECIFIED: _ClassVar[OrgUserRelationshipType]
    SINGLE_ORGANIZATION: _ClassVar[OrgUserRelationshipType]
    MULTIPLE_ORGANIZATIONS: _ClassVar[OrgUserRelationshipType]

class CookiePersistenceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CookiePersistenceType_UNSPECIFIED: _ClassVar[CookiePersistenceType]
    PERSISTENT: _ClassVar[CookiePersistenceType]
    SESSION: _ClassVar[CookiePersistenceType]

class CookieSameSiteSetting(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CookieSameSiteSetting_UNSPECIFIED: _ClassVar[CookieSameSiteSetting]
    LAX_MODE: _ClassVar[CookieSameSiteSetting]
    NONE_MODE: _ClassVar[CookieSameSiteSetting]
UNSPECIFIED: CustomDomainStatus
PENDING: CustomDomainStatus
ACTIVE: CustomDomainStatus
FAILED: CustomDomainStatus
INITIAL: CustomDomainStatus
ASSET_CATEGORY_UNSPECIFIED: AssetCategory
PORTAL_CUSTOMIZATION_IMAGE: AssetCategory
OrgUserRelationshipType_UNSPECIFIED: OrgUserRelationshipType
SINGLE_ORGANIZATION: OrgUserRelationshipType
MULTIPLE_ORGANIZATIONS: OrgUserRelationshipType
CookiePersistenceType_UNSPECIFIED: CookiePersistenceType
PERSISTENT: CookiePersistenceType
SESSION: CookiePersistenceType
CookieSameSiteSetting_UNSPECIFIED: CookieSameSiteSetting
LAX_MODE: CookieSameSiteSetting
NONE_MODE: CookieSameSiteSetting

class CreateCustomDomainRequest(_message.Message):
    __slots__ = ("id", "custom_domain")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    id: str
    custom_domain: str
    def __init__(self, id: _Optional[str] = ..., custom_domain: _Optional[str] = ...) -> None: ...

class CreateCustomDomainResponse(_message.Message):
    __slots__ = ("environment",)
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    environment: Environment
    def __init__(self, environment: _Optional[_Union[Environment, _Mapping]] = ...) -> None: ...

class GetDNSRecordsRequest(_message.Message):
    __slots__ = ("id", "custom_domain")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    id: str
    custom_domain: str
    def __init__(self, id: _Optional[str] = ..., custom_domain: _Optional[str] = ...) -> None: ...

class GetDNSRecordsResponse(_message.Message):
    __slots__ = ("dns_records",)
    DNS_RECORDS_FIELD_NUMBER: _ClassVar[int]
    dns_records: _containers.RepeatedCompositeFieldContainer[DNSRecords]
    def __init__(self, dns_records: _Optional[_Iterable[_Union[DNSRecords, _Mapping]]] = ...) -> None: ...

class DNSRecords(_message.Message):
    __slots__ = ("host_name", "type", "value")
    HOST_NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    host_name: str
    type: str
    value: str
    def __init__(self, host_name: _Optional[str] = ..., type: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class Environment(_message.Message):
    __slots__ = ("id", "create_time", "update_time", "display_name", "domain", "region_code", "type", "custom_domain", "custom_domain_status")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    REGION_CODE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_DOMAIN_STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    display_name: str
    domain: str
    region_code: _commons_pb2.RegionCode
    type: _commons_pb2.EnvironmentType
    custom_domain: str
    custom_domain_status: CustomDomainStatus
    def __init__(self, id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., display_name: _Optional[str] = ..., domain: _Optional[str] = ..., region_code: _Optional[_Union[_commons_pb2.RegionCode, str]] = ..., type: _Optional[_Union[_commons_pb2.EnvironmentType, str]] = ..., custom_domain: _Optional[str] = ..., custom_domain_status: _Optional[_Union[CustomDomainStatus, str]] = ...) -> None: ...

class CreateEnvironment(_message.Message):
    __slots__ = ("display_name", "region_code", "type")
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    REGION_CODE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    region_code: _commons_pb2.RegionCode
    type: _commons_pb2.EnvironmentType
    def __init__(self, display_name: _Optional[str] = ..., region_code: _Optional[_Union[_commons_pb2.RegionCode, str]] = ..., type: _Optional[_Union[_commons_pb2.EnvironmentType, str]] = ...) -> None: ...

class UpdateEnvironment(_message.Message):
    __slots__ = ("display_name",)
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    def __init__(self, display_name: _Optional[str] = ...) -> None: ...

class UpdateEnvironmentDomain(_message.Message):
    __slots__ = ("domain",)
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    domain: str
    def __init__(self, domain: _Optional[str] = ...) -> None: ...

class CreateEnvironmentRequest(_message.Message):
    __slots__ = ("environment",)
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    environment: CreateEnvironment
    def __init__(self, environment: _Optional[_Union[CreateEnvironment, _Mapping]] = ...) -> None: ...

class CreateEnvironmentResponse(_message.Message):
    __slots__ = ("environment",)
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    environment: Environment
    def __init__(self, environment: _Optional[_Union[Environment, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentRequest(_message.Message):
    __slots__ = ("id", "environment")
    ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    environment: UpdateEnvironment
    def __init__(self, id: _Optional[str] = ..., environment: _Optional[_Union[UpdateEnvironment, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentDomainRequest(_message.Message):
    __slots__ = ("id", "environment")
    ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    environment: UpdateEnvironmentDomain
    def __init__(self, id: _Optional[str] = ..., environment: _Optional[_Union[UpdateEnvironmentDomain, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentResponse(_message.Message):
    __slots__ = ("environment",)
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    environment: Environment
    def __init__(self, environment: _Optional[_Union[Environment, _Mapping]] = ...) -> None: ...

class GetEnvironmentRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetEnvironmentResponse(_message.Message):
    __slots__ = ("environment",)
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    environment: Environment
    def __init__(self, environment: _Optional[_Union[Environment, _Mapping]] = ...) -> None: ...

class ListEnvironmentsRequest(_message.Message):
    __slots__ = ("page_size", "page_token")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListEnvironmentsResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "environments")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    environments: _containers.RepeatedCompositeFieldContainer[Environment]
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., environments: _Optional[_Iterable[_Union[Environment, _Mapping]]] = ...) -> None: ...

class DeleteEnvironmentRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GenerateSamlCertificateRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GenerateSamlCertificateResponse(_message.Message):
    __slots__ = ("id", "certificate", "expiry")
    ID_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    id: str
    certificate: str
    expiry: int
    def __init__(self, id: _Optional[str] = ..., certificate: _Optional[str] = ..., expiry: _Optional[int] = ...) -> None: ...

class UpdatePortalCustomizationResponse(_message.Message):
    __slots__ = ("environmentId", "customization_settings")
    ENVIRONMENTID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMIZATION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    environmentId: str
    customization_settings: _struct_pb2.Struct
    def __init__(self, environmentId: _Optional[str] = ..., customization_settings: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class UpdatePortalCustomizationRequest(_message.Message):
    __slots__ = ("id", "customization_settings")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMIZATION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    id: str
    customization_settings: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., customization_settings: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class GetPortalCustomizationRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetPortalCustomizationResponse(_message.Message):
    __slots__ = ("environmentId", "customization_settings")
    ENVIRONMENTID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMIZATION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    environmentId: str
    customization_settings: _struct_pb2.Struct
    def __init__(self, environmentId: _Optional[str] = ..., customization_settings: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class CreateAssetUploadUrlResponse(_message.Message):
    __slots__ = ("upload_url", "fetch_url")
    UPLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    FETCH_URL_FIELD_NUMBER: _ClassVar[int]
    upload_url: str
    fetch_url: str
    def __init__(self, upload_url: _Optional[str] = ..., fetch_url: _Optional[str] = ...) -> None: ...

class CreateAssetUploadUrlRequest(_message.Message):
    __slots__ = ("id", "asset_settings")
    ID_FIELD_NUMBER: _ClassVar[int]
    ASSET_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    id: str
    asset_settings: AssetSettings
    def __init__(self, id: _Optional[str] = ..., asset_settings: _Optional[_Union[AssetSettings, _Mapping]] = ...) -> None: ...

class AssetSettings(_message.Message):
    __slots__ = ("category", "extension")
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    category: AssetCategory
    extension: str
    def __init__(self, category: _Optional[_Union[AssetCategory, str]] = ..., extension: _Optional[str] = ...) -> None: ...

class UpdateFeaturesRequest(_message.Message):
    __slots__ = ("id", "features")
    ID_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    id: str
    features: _containers.RepeatedCompositeFieldContainer[EnvironmentFeature]
    def __init__(self, id: _Optional[str] = ..., features: _Optional[_Iterable[_Union[EnvironmentFeature, _Mapping]]] = ...) -> None: ...

class EnableFSAFeatureRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetFeaturesRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetFeaturesResponse(_message.Message):
    __slots__ = ("features",)
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    features: _containers.RepeatedCompositeFieldContainer[EnvironmentFeature]
    def __init__(self, features: _Optional[_Iterable[_Union[EnvironmentFeature, _Mapping]]] = ...) -> None: ...

class EnableFeatureRequest(_message.Message):
    __slots__ = ("id", "feature_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    FEATURE_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    feature_id: str
    def __init__(self, id: _Optional[str] = ..., feature_id: _Optional[str] = ...) -> None: ...

class DisableFeatureRequest(_message.Message):
    __slots__ = ("id", "feature_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    FEATURE_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    feature_id: str
    def __init__(self, id: _Optional[str] = ..., feature_id: _Optional[str] = ...) -> None: ...

class EnvironmentFeature(_message.Message):
    __slots__ = ("name", "enabled")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    name: str
    enabled: bool
    def __init__(self, name: _Optional[str] = ..., enabled: bool = ...) -> None: ...

class GetEnvironmentSessionSettingsRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetEnvironmentUserManagementRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetEnvironmentSessionSettingsResponse(_message.Message):
    __slots__ = ("session_settings",)
    SESSION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    session_settings: SessionSettings
    def __init__(self, session_settings: _Optional[_Union[SessionSettings, _Mapping]] = ...) -> None: ...

class GetEnvironmentUserManagementResponse(_message.Message):
    __slots__ = ("user_management",)
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    user_management: UserManagement
    def __init__(self, user_management: _Optional[_Union[UserManagement, _Mapping]] = ...) -> None: ...

class CreateEnvironmentSessionSettingsRequest(_message.Message):
    __slots__ = ("id", "session_settings")
    ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    id: str
    session_settings: SessionSettings
    def __init__(self, id: _Optional[str] = ..., session_settings: _Optional[_Union[SessionSettings, _Mapping]] = ...) -> None: ...

class CreateEnvironmentUserManagementRequest(_message.Message):
    __slots__ = ("id", "user_management")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_management: UserManagement
    def __init__(self, id: _Optional[str] = ..., user_management: _Optional[_Union[UserManagement, _Mapping]] = ...) -> None: ...

class CreateEnvironmentSessionSettingsResponse(_message.Message):
    __slots__ = ("environment_id", "session_settings")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    session_settings: SessionSettings
    def __init__(self, environment_id: _Optional[str] = ..., session_settings: _Optional[_Union[SessionSettings, _Mapping]] = ...) -> None: ...

class CreateEnvironmentUserManagementResponse(_message.Message):
    __slots__ = ("environment_id", "user_management")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    user_management: UserManagement
    def __init__(self, environment_id: _Optional[str] = ..., user_management: _Optional[_Union[UserManagement, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentSessionSettingsRequest(_message.Message):
    __slots__ = ("id", "session_settings")
    ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    id: str
    session_settings: SessionSettings
    def __init__(self, id: _Optional[str] = ..., session_settings: _Optional[_Union[SessionSettings, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentUserManagementRequest(_message.Message):
    __slots__ = ("id", "user_management")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_management: UserManagement
    def __init__(self, id: _Optional[str] = ..., user_management: _Optional[_Union[UserManagement, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentSessionSettingsResponse(_message.Message):
    __slots__ = ("environment_id", "session_settings")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    session_settings: SessionSettings
    def __init__(self, environment_id: _Optional[str] = ..., session_settings: _Optional[_Union[SessionSettings, _Mapping]] = ...) -> None: ...

class UpdateEnvironmentUserManagementResponse(_message.Message):
    __slots__ = ("environment_id", "user_management")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    user_management: UserManagement
    def __init__(self, environment_id: _Optional[str] = ..., user_management: _Optional[_Union[UserManagement, _Mapping]] = ...) -> None: ...

class SessionSettings(_message.Message):
    __slots__ = ("access_token_expiry", "client_access_token_expiry", "absolute_session_timeout", "session_management_enabled", "idle_session_timeout", "idle_session_enabled", "cookie_persistence_type", "cookie_same_site_setting", "cookie_custom_domain")
    ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_SESSION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    SESSION_MANAGEMENT_ENABLED_FIELD_NUMBER: _ClassVar[int]
    IDLE_SESSION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    IDLE_SESSION_ENABLED_FIELD_NUMBER: _ClassVar[int]
    COOKIE_PERSISTENCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    COOKIE_SAME_SITE_SETTING_FIELD_NUMBER: _ClassVar[int]
    COOKIE_CUSTOM_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    access_token_expiry: _wrappers_pb2.Int32Value
    client_access_token_expiry: _wrappers_pb2.Int32Value
    absolute_session_timeout: _wrappers_pb2.Int32Value
    session_management_enabled: _wrappers_pb2.BoolValue
    idle_session_timeout: _wrappers_pb2.Int32Value
    idle_session_enabled: _wrappers_pb2.BoolValue
    cookie_persistence_type: CookiePersistenceType
    cookie_same_site_setting: CookieSameSiteSetting
    cookie_custom_domain: _wrappers_pb2.StringValue
    def __init__(self, access_token_expiry: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., client_access_token_expiry: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., absolute_session_timeout: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., session_management_enabled: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., idle_session_timeout: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., idle_session_enabled: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., cookie_persistence_type: _Optional[_Union[CookiePersistenceType, str]] = ..., cookie_same_site_setting: _Optional[_Union[CookieSameSiteSetting, str]] = ..., cookie_custom_domain: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class UserManagement(_message.Message):
    __slots__ = ("allow_duplicate_user_identities", "allow_multiple_memberships", "allow_organization_signup", "org_user_relationship", "enable_max_users_limit", "max_users_limit", "invitation_expiry", "organization_meta_name")
    ALLOW_DUPLICATE_USER_IDENTITIES_FIELD_NUMBER: _ClassVar[int]
    ALLOW_MULTIPLE_MEMBERSHIPS_FIELD_NUMBER: _ClassVar[int]
    ALLOW_ORGANIZATION_SIGNUP_FIELD_NUMBER: _ClassVar[int]
    ORG_USER_RELATIONSHIP_FIELD_NUMBER: _ClassVar[int]
    ENABLE_MAX_USERS_LIMIT_FIELD_NUMBER: _ClassVar[int]
    MAX_USERS_LIMIT_FIELD_NUMBER: _ClassVar[int]
    INVITATION_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_META_NAME_FIELD_NUMBER: _ClassVar[int]
    allow_duplicate_user_identities: _wrappers_pb2.BoolValue
    allow_multiple_memberships: _wrappers_pb2.BoolValue
    allow_organization_signup: _wrappers_pb2.BoolValue
    org_user_relationship: OrgUserRelationshipType
    enable_max_users_limit: _wrappers_pb2.BoolValue
    max_users_limit: _wrappers_pb2.Int32Value
    invitation_expiry: _wrappers_pb2.UInt32Value
    organization_meta_name: _wrappers_pb2.StringValue
    def __init__(self, allow_duplicate_user_identities: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., allow_multiple_memberships: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., allow_organization_signup: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., org_user_relationship: _Optional[_Union[OrgUserRelationshipType, str]] = ..., enable_max_users_limit: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., max_users_limit: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., invitation_expiry: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., organization_meta_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class GetContextRequest(_message.Message):
    __slots__ = ("environment_id",)
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    def __init__(self, environment_id: _Optional[str] = ...) -> None: ...

class GetContextResponse(_message.Message):
    __slots__ = ("context",)
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    context: _struct_pb2.Struct
    def __init__(self, context: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class UpdateContextRequest(_message.Message):
    __slots__ = ("environment_id", "context")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    context: _struct_pb2.Struct
    def __init__(self, environment_id: _Optional[str] = ..., context: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class GetCurrentSessionRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetCurrentSessionResponse(_message.Message):
    __slots__ = ("session_expiry", "access_token_expiry", "organization_id", "subject", "email")
    SESSION_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    session_expiry: _timestamp_pb2.Timestamp
    access_token_expiry: _timestamp_pb2.Timestamp
    organization_id: str
    subject: str
    email: str
    def __init__(self, session_expiry: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., access_token_expiry: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., organization_id: _Optional[str] = ..., subject: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...

class ResourceMetadata(_message.Message):
    __slots__ = ("type", "identifiers")
    class ResourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        organization: _ClassVar[ResourceMetadata.ResourceType]
        connection: _ClassVar[ResourceMetadata.ResourceType]
        auth_request: _ClassVar[ResourceMetadata.ResourceType]
    organization: ResourceMetadata.ResourceType
    connection: ResourceMetadata.ResourceType
    auth_request: ResourceMetadata.ResourceType
    TYPE_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIERS_FIELD_NUMBER: _ClassVar[int]
    type: ResourceMetadata.ResourceType
    identifiers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, type: _Optional[_Union[ResourceMetadata.ResourceType, str]] = ..., identifiers: _Optional[_Iterable[str]] = ...) -> None: ...

class ScalekitResourceRequest(_message.Message):
    __slots__ = ("resources",)
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    resources: _containers.RepeatedCompositeFieldContainer[ResourceMetadata]
    def __init__(self, resources: _Optional[_Iterable[_Union[ResourceMetadata, _Mapping]]] = ...) -> None: ...

class ScalekitResourceResponse(_message.Message):
    __slots__ = ("resources",)
    class ResourcesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Struct
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    resources: _containers.MessageMap[str, _struct_pb2.Struct]
    def __init__(self, resources: _Optional[_Mapping[str, _struct_pb2.Struct]] = ...) -> None: ...



from typing import Optional

from scalekit.core import CoreClient
from scalekit.v1.connections.connections_pb2 import *
from scalekit.v1.connections.connections_pb2_grpc import ConnectionServiceStub


class ConnectionClient:
    """Class definition for Connection Client"""

    def __init__(self, core_client: CoreClient):
        """
        Initializer for connection client

        :param core_client    : CoreClient Object
        :type                 : ``` obj ```
        :returns
            None
        """
        self.core_client = core_client
        self.connection_service = ConnectionServiceStub(
            self.core_client.grpc_secure_channel
        )

    def get_connection(
        self, organization_id: str, conn_id: str
    ) -> GetConnectionResponse:
        """
        Method to get connection object

        :param organization_id  : Client organization id to get connection
        :type                   : ``` str ```
        :param conn_id          : Client connection id to get connection
        :type                   : ``` str ```
        :returns
            Connection Response
        """
        return self.core_client.grpc_exec(
            self.connection_service.GetConnection.with_call,
            GetConnectionRequest(organization_id=organization_id, id=conn_id),
        )

    def list_connections_by_domain(self, domain: str, include: Optional[str] = None) -> ListConnectionsResponse:
        """
        Method to get connection object by domain

        :param domain     : Client domain id to get connections
        :type             : ``` str ```
        :param include    : Return active connections or all, E.g. - 'all'
        :type             : ``` str ```

        :returns:
            List Connections Response
        """
        return self.core_client.grpc_exec(
            self.connection_service.ListConnections.with_call,
            ListConnectionsRequest(domain=domain, include=include),
        )

    def list_connections(self, organization_id: str, include: Optional[str] = None) -> ListConnectionsResponse:
        """
        Method to list connections

        :param organization_id : Client organization id to get connections
        :type                  : ``` str ```
        :param include         : Return active connections or all, E.g. - 'all'
        :type                  : ``` str ```

        :returns:
            List Connections Response
        """
        return self.core_client.grpc_exec(
            self.connection_service.ListConnections.with_call,
            ListConnectionsRequest(organization_id=organization_id, include=include),
        )

    def enable_connection(
        self, organization_id: str, conn_id: str
    ) -> ToggleConnectionResponse:
        """
        Method to enable connection

        :param organization_id  : Client organization id to enable connection
        :type                   : ``` str ```
        :param conn_id          : Client connection id to enable connection
        :type                   : ``` str ```
        :returns
            Enable Connection Response
        """
        return self.core_client.grpc_exec(
            self.connection_service.EnableConnection.with_call,
            ToggleConnectionRequest(organization_id=organization_id, id=conn_id),
        )

    def disable_connection(
        self, organization_id: str, conn_id: str
    ) -> ToggleConnectionResponse:
        """
        Method to disable connection

        :param organization_id  : Client organization id to disable connection
        :type                   : ``` str ```
        :param conn_id          : Client connection id to disable connection
        :type                   : ``` str ```
        :returns
            Disable Connection Response
        """
        return self.core_client.grpc_exec(
            self.connection_service.DisableConnection.with_call,
            ToggleConnectionRequest(organization_id=organization_id, id=conn_id),
        )

    def create_connection(self, organization_id: str, connection: CreateConnection) -> CreateConnectionResponse:
        """
        Method to create a new connection

        :param organization_id  : Organization id to create connection for
        :type                   : ``` str ```
        :param connection       : CreateConnection object with expected values for conn creation
        :type                   : ``` obj ```

        :returns:
            Create Connection Response
        """
        return self.core_client.grpc_exec(
            self.connection_service.CreateConnection.with_call,
            CreateConnectionRequest(organization_id=organization_id, connection=connection),
        )
    
    def delete_connection(self, organization_id: str, connection_id: str):
        """
        Method to delete a connection based in given organization and connection id

        :param organization_id  : Organization id to delete connection for
        :type                   : ``` str ```
        :param connection_id    : Connection id of connection to be deleted
        :type                   : ``` str ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.connection_service.DeleteConnection.with_call,
            DeleteConnectionRequest(organization_id=organization_id, id=connection_id),
        )
